@@ -1,7 +1,5 @@
 (**************************************************************************)
-(*  -*- tuareg -*-                                                        *)
-(*                                                                        *)
-(*  Copyright (C) 2017,2018,2019 Yann Régis-Gianas, Nicolas Jeannerod,    *)
+(*  Copyright (C) 2017-2023 Yann Régis-Gianas, Nicolas Jeannerod,         *)
 (*  Ralf Treinen.                                                         *)
 (*                                                                        *)
 (*  This is free software: you can redistribute it and/or modify it       *)
@@ -128,7 +126,7 @@ let interpret aliases cst =
   let level = ref 0 in
   let at_toplevel () = !level = 0 in
   let analyzer = object
-      inherit [_] CST.iter as super
+      inherit [_] CSTVisitors.iter as super
       method! visit_compound_command env cmd =
         incr level;
         super # visit_compound_command env cmd;
